<?php
/**
 * Namespace Tecfood\Integracao\Services
 *
 * PHP version 5
 *
 * @category Php
 * @package  Tecfood\Integracao\Services
 * @author   andreteixeira <andre.teixeira@teknisa.com>
 * @license  www.teknisa.com Teknisa
 * @link     http://localhost:9090/tecfood
 */
namespace Teknisa\Logic\IntNutrientes\Services;
use Geral\Util\Ambiente;
use Setforms2\Shared\Registry;
use Teknisa\Entities\SitProdutoint;

/**
 * Class RecebeProdutos Service
 *
 * PHP version 5
 *
 * @category Php
 * @package  Tecfood\Integracao\Services
 * @author   andreteixeira <andre.teixeira@teknisa.com>
 * @license  www.teknisa.com Teknisa
 * @link     http://localhost:9090/tecfood
 */
class RecebeProdutos
{

    /**
     * Recebe Produtos no servidor da Teknisa
     *
     * @param String $json JSON
     *
     * @return string.
     */
    public static function recebeProdutos($json)
    {
        //Atribui os valores às variáveis
        $nrremessa = $json['NRREMESSA'];
        $nrorgint  = $json['NRORGINT'];
        $qtprodenv = $json['QTPRODENV'];
        $produtos  = $json['PRODUTOS'];

        //Validação
        if (count($produtos) != $qtprodenv) {
            //$resp = array('msg_ger07600_quantidadeRecebidaIncorreta', array());
            $resp = tk_get_message_by_name(
                'msg_ger07600_quantidadeRecebidaIncorreta'
            );
        } else {
            $resp = self::insereProdutos($nrremessa, $nrorgint, $produtos);
        }

        return $resp;
    }

    /**
     * Insere Produtos
     *
     * @param String $nrremessa Número da Remessa
     * @param String $nrorgint  Organização de Integração
     * @param Array  $produtos  Array de Produtos
     *
     * @return null
     */
    public static function insereProdutos ($nrremessa, $nrorgint, $produtos)
    {
        $resp = null;
        //
        if (is_array($produtos)) {
            $conn = Registry::getEntityManager();
            try {
                $conn->beginTransaction();
                //
                foreach ($produtos as $produto) {
                    if (SitProdutoint::produtoExistente(
                        $nrorgint, $produto['CDPRODUTO']
                    ) === false) {
                        $produtoint = new SitProdutoint();
                        $produtoint->insereProdutoDe(
                            $nrorgint, $nrremessa, $produto['CDPRODUTO'],
                            $produto['NMPRODUTO'], $produto['SGUNIDADE'],
                            $produto['VRPESOUNID'], $produto['OBSERVACAO'],
                            $produto['DATA'],
                            Ambiente::getCdOperador(),
                            Ambiente::getNrorg()
                        );
                    }
                }
                //
                $conn->flush();
                $conn->commit();
            } catch (\Exception $e) {
                $conn->rollback();
                //$resp = array($e->getMessage(), array());
                $resp = tk_get_message_by_name($e->getMessage());
            }
        }
        //
        return $resp;
    }

} 